Index: ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h |
diff --git a/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h b/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h |
index 63d61de296d88c0def674cfd5651de5ed3725ebb..99071cbc68fc4a1e96e97add1ff9187b49e00849 100644 |
--- a/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h |
+++ b/ios/chrome/browser/ui/content_suggestions/content_suggestions_data_sink.h |
@@ -5,9 +5,9 @@ |
#ifndef IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_DATA_SINK_H_ |
#define IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_DATA_SINK_H_ |
+@class CollectionViewItem; |
@class ContentSuggestionIdentifier; |
@class ContentSuggestionsSectionInformation; |
-class GURL; |
// Data sink for the ContentSuggestions. It will be notified when new data needs |
// to be pulled. |
@@ -36,8 +36,8 @@ class GURL; |
// now, removing the current content. |
- (void)reloadSection:(ContentSuggestionsSectionInformation*)sectionInfo; |
-// Notifies the Data Sink that a new favicon is available for the |URL|. |
-- (void)faviconAvailableForURL:(const GURL&)URL; |
+// Notifies the Data Sink that a new favicon is available for the |item|. |
+- (void)faviconAvailableForItem:(CollectionViewItem<SuggestedContent>*)item; |
@end |